@@ -76,7 +76,7 @@ class Draw_data
   attr_accessor :tone, :tone_i
   attr_accessor :vector
   attr_accessor :transpose
-  attr_accessor :type, :map_type
+  attr_accessor :type, :map_type, :map_draw, :map_pole
   attr_accessor :title
 #  attr_accessor :missing_value
   attr_reader :axis_x, :axis_y
@@ -277,6 +277,8 @@ class Draw
     @y_unit = draw_data.axis_y.unit
     @type = draw_data.type
     @maptype = draw_data.map_type
+    @map_draw = draw_data.map_draw
+    @map_pole = draw_data.map_pole
     @cont = draw_data.cont
     @cont_i = draw_data.cont_i
     @tone = draw_data.tone
@@ -482,6 +484,9 @@ class Draw
       @fig.figure_set('DCL::uxsttl("t", title, 0 )', __FILE__,__LINE__)
     elsif type==MAP then
       @fig.figure_set("DCL::umpglb", __FILE__,__LINE__)
+		if @map_draw
+		  @fig.figure_set('DCL::umpmap("coast_world")', __FILE__,__LINE__)
+	   end
       @fig.figure_set('DCL::sglset("LCLIP", false )', __FILE__,__LINE__)
       @fig.figure_set("title = \"#{title}\"", __FILE__,__LINE__)
       @fig.figure_set("DCL::sgtxzv((vxmax+vxmin)/2,vymax+0.02,title,0.02,0.0,0,2)", __FILE__,__LINE__)
@@ -497,9 +502,11 @@ class Draw
     @fig.figure_clear
     if @type == MAP then
       itr = @maptype
+      lon,lat,rot = @map_pole
       @fig.frame_set("DCL::grfrm", __FILE__,__LINE__)
       @fig.frame_set("DCL::grsvpt(vxmin,vxmax,vymin,vymax)", __FILE__,__LINE__)
-      @fig.frame_set("DCL::grsmpl(0.0,90.0,0.0)", __FILE__,__LINE__)
+      @fig.frame_set("DCL::grswnd(xmin,xmax,ymin,ymax)", __FILE__,__LINE__)
+      @fig.frame_set("DCL::grsmpl(#{lon},#{lat},#{rot})", __FILE__,__LINE__)
       @fig.frame_set("DCL::grstrn(#{itr})", __FILE__,__LINE__)
       @fig.frame_set("DCL::umpfit", __FILE__,__LINE__)
       @fig.frame_set("DCL::grstrf", __FILE__,__LINE__)
@@ -517,7 +524,6 @@ class Draw
       draw_1d(@title)
     elsif @type==CONTOUR || @type==MAP || @type==VECTOR then
       draw_2d(@title,@type)
-      # draw map if @type==MAP
     end
     DCL::zgsdrw(drawing_area)
     DCL::zgspmp(@pixmap)
